@@ -375,6 +375,7 @@ PyMODINIT_FUNC initiBase(void)
     ADD_ENUM(iBaseAdjCost,"some_order_1",    iBase_SOME_ORDER_1);
     ADD_ENUM(iBaseAdjCost,"some_order_logn", iBase_SOME_ORDER_LOGN);
     ADD_ENUM(iBaseAdjCost,"some_order_n",    iBase_SOME_ORDER_N);
+    ADD_ENUM(iBaseAdjCost,"available",       iBase_AVAILABLE);
 
     /***** initialize storage order enum *****/
     REGISTER_CLASS(m,"StorageOrder",iBaseStorageOrder);
@@ -406,10 +407,6 @@ PyMODINIT_FUNC initiBase(void)
     iBaseArr_Type.tp_alloc = PyType_GenericAlloc;
     iBaseArr_Type.tp_free  = _PyObject_Del;
     REGISTER_CLASS_BASE(m,"Array",iBaseArr,PyArray);
-
-    /* eliminate warnings */
-    (void)PyArray_TryFromObject;
-    (void)PyArray_ToVectors;
 }
 
 #include "iBase_array.inl"
