@@ -238,23 +238,50 @@ iMeshObj_getadjTable(iMesh_Object *self,void *closure)
     return PyArray_NewFromOut(2,dims,NPY_INT,&adjtable);
 }
 
-static PyObject *
-iMeshObj_areEHValid(iMesh_Object *self,PyObject *args,PyObject *kw)
+static int
+iMeshObj_setadjTable(iMesh_Object *self,PyObject *value,void *closure)
 {
-    static char *kwlist[] = {"reset",0};
+    PyObject *adj;
+    int adjtable[16];
     int err;
-    PyObject *reset;
 
-    int invariant;
+    if(value == NULL)
+    {
+        PyErr_SetString(PyExc_TypeError, 
+                        "Cannot delete the adjTable attribute");
+        return -1;
+    }
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!",kwlist,&PyBool_Type,&reset))
-        return NULL;
+    adj = PyArray_FROMANY(value,NPY_INT,1,2,NPY_C_CONTIGUOUS);
+    if ((PyArray_NDIM(adj) == 1 && PyArray_DIM(adj,0) != 16) ||
+        (PyArray_NDIM(adj) == 2 && (PyArray_DIM(adj,0) != 4 ||
+                                    PyArray_DIM(adj,1) != 4))) {
+        PyErr_SetString(PyExc_ValueError, 
+                        "expected 4x4 matrix of adjacency values");
+        return -1;
+    }
+    /* copy the values since setAdjTable modifies them */
+    memcpy(adjtable,PyArray_DATA(adj),sizeof(int)*16);
+    Py_DECREF(adj);
 
-    iMesh_areEHValid(self->handle,(reset==Py_True),&invariant,&err);
+    iMesh_setAdjTable(self->handle,adjtable,16,&err);
+    if(checkError(self->handle,err))
+        return -1;
+
+    return 0;
+}
+
+static PyObject *
+iMeshObj_optimize(iMesh_Object *self)
+{
+    int err;
+    int invalidated;
+
+    iMesh_optimize(self->handle,&invalidated,&err);
     if(checkError(self->handle,err))
         return NULL;
 
-    return PyBool_FromLong(invariant);
+    return PyBool_FromLong(invalidated);
 }
 
 static PyObject *
@@ -931,7 +958,7 @@ iMeshObj_hash(iMesh_Object *self)
 }
 
 static PyMethodDef iMeshObj_methods[] = {
-    IMESH_METHOD(iMesh, areEHValid,    METH_VARARGS|METH_KEYWORDS),
+    IMESH_METHOD(iMesh, optimize,      METH_NOARGS),
     IMESH_METHOD(iMesh, createVtx,     METH_VARARGS|METH_KEYWORDS),
     IMESH_METHOD(iMesh, createEnt,     METH_VARARGS|METH_KEYWORDS),
     IMESH_METHOD(iMesh, createEntArr,  METH_VARARGS|METH_KEYWORDS),
@@ -955,7 +982,7 @@ static PyGetSetDef iMeshObj_getset[] = {
     IMESH_GET   (iMesh, rootSet),
     IMESH_GETSET(iMesh, geometricDimension),
     IMESH_GET   (iMesh, defaultStorage),
-    IMESH_GET   (iMesh, adjTable),
+    IMESH_GETSET(iMesh, adjTable),
     {0}
 };
 
