@@ -27,15 +27,10 @@
 "retrieving adjacencies between entities of dimension *i* to entities\n"       \
 "of dimension *j*."
 
-#define IMESHDOC_iMesh_areEHValid \
-"Return whether entity handles have changed since last reset or\n"             \
-"since instance construction. If true, it is not guaranteed that a\n"          \
-"handle from before the last call to this function represents the\n"           \
-"same entity as the same handle value does now. If *reset* is true,\n"         \
-"resets the starting point for this function.\n\n"                             \
-":param reset: If true, perform a reset on the starting point after\n"         \
-"              which handles are invariant.\n"                                 \
-":return: True iff entity handles have changed"
+#define IMESHDOC_iMesh_optimize \
+"Request that the mesh optimize the storage of its entities, possibly\n"       \
+"rearranging the entities and invalidating extisting handles.\n\n"             \
+":return: True if entity handles have changed"
 
 #define IMESHDOC_iMesh_createVtx \
 "Create a vertex or array of vertices with the specified\n"                    \
