@@ -442,9 +442,6 @@ PyMODINIT_FUNC initiRel(void)
     ADD_ENUM(iRelStatus,"active",    iRel_ACTIVE);
     ADD_ENUM(iRelStatus,"inactive",  iRel_INACTIVE);
     ADD_ENUM(iRelStatus,"not_exist", iRel_NOTEXIST);
-
-    /* eliminate warnings */
-    (void)PyArray_ToVectors;
 }
 
 /* Include source files so that everything is in one translation unit */
