@@ -4,6 +4,27 @@
 #include <numpy/arrayobject.h>
 #include "iBase_Python.h"
 
+#ifdef __GNUC__
+#define MAYBE_UNUSED __attribute__ ((unused))
+#else
+#define MAYBE_UNUSED
+#endif
+
+static PyObject *
+PyArray_NewFromSubStrided(PyTypeObject *type,int nd,npy_intp *dims,
+                          npy_intp *strides,int typenum,void *data,
+                          PyObject *base) MAYBE_UNUSED;
+static PyObject *
+PyArray_TryFromObject(PyObject *obj,int typenum,int min_depth,int max_depth)
+    MAYBE_UNUSED;
+static int
+PyArray_CheckVectors(PyObject *obj,int nd,npy_intp vec_dim,int index)
+    MAYBE_UNUSED;
+static PyObject *
+PyArray_ToVectors(PyObject *obj,int typenum,int nd,npy_intp vec_dim,int index)
+    MAYBE_UNUSED;
+
+
 #define PyArray_NewFromOut(nd,dims,typenum,out)                                \
     PyArray_NewFromOutSubStrided(&PyArray_Type,(nd),(dims),NULL,(typenum),     \
                                  (out))
