@@ -1,10 +1,10 @@
 from itaps.helpers import *
-import unittest
+from .. import testhelper as unittest
 import numpy
 import sys
 
 if sys.hexversion >= 0x020600f0:
-    from itaps.namedtuple import namedtuple
+    from collections import namedtuple
     point = namedtuple('point', 'x y')
 else:
     point = lambda *args: args
@@ -19,52 +19,47 @@ class TestOffsetList(unittest.TestCase):
 
     def testSingleBasic(self):
         self.assertEqual(len(self.single), 4)
-        self.assert_((self.single[0] == [0, 1, 2]).all())
-        self.assert_((self.single.offsets == numpy.arange(0, 13, 3)).all())
-        self.assert_((self.single.raw == numpy.arange(12)).all())
+        self.assertArray(self.single[0], [0, 1, 2])
+        self.assertArray(self.single.offsets, numpy.arange(0, 13, 3))
+        self.assertArray(self.single.data, numpy.arange(12))
 
     def testSingleIndex(self):
-        for hunk, i in zip(self.single, range(len(self.single))):
+        for i, hunk in enumerate(self.single):
             self.assertEqual(len(hunk), 3)
             self.assertEqual(self.single.length(i), 3)
-            self.assert_((hunk == numpy.arange(i*3, (i+1)*3)).all())
+            self.assertArray(hunk, numpy.arange(i*3, (i+1)*3))
 
         self.assertRaises(IndexError, lambda: self.single[4])
         self.assertRaises(IndexError, lambda: self.single[0,3])
 
     def testMultiBasic(self):
         self.assertEqual(len(self.multi), 4)
-        self.assert_((self.multi[0][0] == [ 0,  1,  2]).all())
-        self.assert_((self.multi[0][1] == [12, 13, 14]).all())
-        self.assert_((self.multi.raw[0] == numpy.arange(12)).all())
-        self.assert_((self.multi.raw[1] == numpy.arange(12,24)).all())
+        self.assertArray(self.multi[0][0], [ 0,  1,  2])
+        self.assertArray(self.multi[0][1], [12, 13, 14])
+        self.assertArray(self.multi.data[0], numpy.arange(12))
+        self.assertArray(self.multi.data[1], numpy.arange(12,24))
 
     def testMultiIndex(self):
-        for hunk, i in zip(self.multi, range(len(self.multi))):
+        for i, hunk in enumerate(self.multi):
             self.assertEqual(len(hunk), 2)
             self.assertEqual(len(hunk[0]), 3)
             self.assertEqual(self.multi.length(i), 3)
-            self.assert_((hunk[0] == numpy.arange(i*3,    (i+1)*3)   ).all())
-            self.assert_((hunk[1] == numpy.arange(i*3+12, (i+1)*3+12)).all())
+            self.assertArray(hunk[0], numpy.arange(i*3,    (i+1)*3)   )
+            self.assertArray(hunk[1], numpy.arange(i*3+12, (i+1)*3+12))
 
         self.assertRaises(IndexError, lambda: self.multi[4])
         self.assertRaises(IndexError, lambda: self.multi[0,3])
 
     def testMultiKey(self):
-        for hunk, i in zip(self.multi.slice(0), range(len(self.multi))):
-            self.assert_((hunk == numpy.arange(i*3, (i+1)*3)).all())
-        for hunk, i in zip(self.multi.slice(1), range(len(self.multi))):
-            self.assert_((hunk == numpy.arange(i*3+12, (i+1)*3+12)).all())
+        for i, hunk in enumerate(self.multi.slice(0)):
+            self.assertArray(hunk, numpy.arange(i*3, (i+1)*3))
+        for i, hunk in enumerate(self.multi.slice(1)):
+            self.assertArray(hunk, numpy.arange(i*3+12, (i+1)*3+12))
 
         self.assertRaises(AttributeError, lambda: self.multi.non_existant)
 
     if sys.hexversion >= 0x020600f0:
         def testMultiKeyNamed(self):
-            print self.multi.fields
             self.assertEqual(self.multi.fields, ('x', 'y'))
-            self.assert_((self.multi.x.raw == self.multi.slice('x').raw).all())
-            self.assert_((self.multi.x.raw == self.multi.slice(0).raw).all())
-
-
-if __name__ == '__main__':
-    unittest.main()
+            self.assertArray(self.multi.x.data, self.multi.slice('x').data)
+            self.assertArray(self.multi.x.data, self.multi.slice(0).data)
