@@ -1,5 +1,5 @@
 from itaps import iBase, iGeom
-import unittest
+from .. import testhelper as unittest
 
 class TestAdj(unittest.TestCase):
     def setUp(self):
@@ -15,7 +15,7 @@ class TestAdj(unittest.TestCase):
 
     def testAdj(self):
         adj = self.geom.getEntAdj(self.volume, iBase.Type.face)
-        self.assert_((adj == self.faces).all())
+        self.assertArray(adj, self.faces)
 
         adj = self.geom.getEntAdj(self.faces, iBase.Type.edge)
 
@@ -24,10 +24,10 @@ class TestAdj(unittest.TestCase):
             self.assertEqual(adj.length(i), 4)
             curr = adj[i]
             for j in curr:
-                self.assert_(j in self.edges)
+                self.assertTrue(j in self.edges)
 
             for j in range(adj.length(i)):
-                self.assert_(adj[i,j] in self.edges)
+                self.assertTrue(adj[i,j] in self.edges)
 
         self.assertRaises(IndexError, adj.__getitem__, (0,4))
 
@@ -36,7 +36,7 @@ class TestAdj(unittest.TestCase):
                                      iBase.Type.edge)
         self.assertEqual(len(adj), len(self.edges))
         for i in adj:
-            self.assert_(i in self.edges)
+            self.assertTrue(i in self.edges)
 
         adj = self.geom.getEnt2ndAdj(self.faces, iBase.Type.edge,
                                      iBase.Type.vertex)
@@ -46,20 +46,17 @@ class TestAdj(unittest.TestCase):
             self.assertEqual(adj.length(i), 4)
             curr = adj[i]
             for j in curr:
-                self.assert_(j in self.verts)
+                self.assertTrue(j in self.verts)
 
             for j in range(adj.length(i)):
-                self.assert_(adj[i,j] in self.verts)
+                self.assertTrue(adj[i,j] in self.verts)
 
         self.assertRaises(IndexError, adj.__getitem__, (0,4))
 
     def testIsAdj(self):
-        self.assert_(self.geom.isEntAdj(self.volume, self.faces[0]))
-        self.assert_(self.geom.isEntAdj([self.volume], self.faces[0:1]).all())
-        self.assert_(self.geom.isEntAdj(self.volume, self.faces).all())
-        self.assert_(self.geom.isEntAdj(self.faces, self.volume).all())
-        self.assert_(self.geom.isEntAdj([self.volume]*6, self.faces).all())
-
-if __name__ == '__main__':
-    unittest.main()
-
+        self.assertTrue(self.geom.isEntAdj(self.volume, self.faces[0]))
+        self.assertTrue(self.geom.isEntAdj([self.volume], self.faces[0:1])
+                        .all())
+        self.assertTrue(self.geom.isEntAdj(self.volume, self.faces).all())
+        self.assertTrue(self.geom.isEntAdj(self.faces, self.volume).all())
+        self.assertTrue(self.geom.isEntAdj([self.volume]*6, self.faces).all())
