@@ -9,14 +9,18 @@ class TestBasic(unittest.TestCase):
         self.mesh.geometricDimension = 2
         self.assertEqual(self.mesh.geometricDimension, 2)
 
-    def testEHValidity(self):
-        self.assertTrue(self.mesh.areEHValid(True))
+    def testOptimize(self):
+        self.mesh.optimize()
 
     def testDefaultStorage(self):
         self.assertTrue(isinstance(self.mesh.defaultStorage, int))
 
     def testAdjTable(self):
         self.assertEqual(self.mesh.adjTable.shape, (4,4))
+        self.mesh.adjTable = [[0, 0, 0, 0],
+                              [0, 0, 0, 0],
+                              [0, 0, 0, 0],
+                              [0, 0, 0, 0]]
 
     def testRootSet(self):
         root = self.mesh.rootSet
