@@ -110,7 +110,7 @@ class TestEntSet(unittest.TestCase):
 
         self.set.removeChild(sub)
 
-        self.assertTrue(not self.set.isChild(sub))
+        self.assertFalse(self.set.isChild(sub))
         self.assertEqual(self.set.getNumChildren(), 0)
         self.assertEqual(sub.getNumParents(),  0)
 
