@@ -310,6 +310,78 @@ class TestTags(unittest.TestCase):
         self.assertRaises(iBase.TagNotFoundError, lambda: self.s3tag[self.set])
 
 
+    def testRootSetRawData(self):
+        self.btag[self.mesh] = 42
+        self.assertEqual(self.btag[self.mesh], 42)
+
+        del self.btag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.btag[self.mesh])
+
+    def testRootSetIntData(self):
+        self.itag[self.mesh] = 42
+        self.assertEqual(self.itag[self.mesh], 42)
+
+        del self.itag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.itag[self.mesh])
+
+    def testRootSetDblData(self):
+        self.dtag[self.mesh] = 42
+        self.assertEqual(self.dtag[self.mesh], 42)
+
+        del self.dtag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.dtag[self.mesh])
+        
+    def testRootSetEHData(self):
+        self.etag[self.mesh] = self.ent
+        self.assertEqual(self.etag[self.mesh], self.ent)
+
+        del self.etag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.etag[self.mesh])
+
+    def testRootSetESHData(self):
+        self.stag[self.mesh] = self.set
+        self.assertEqual(self.stag[self.mesh], self.set)
+
+        del self.stag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.stag[self.mesh])
+
+
+    def testRootSetRawArrData(self):
+        self.b3tag[self.mesh] = [42]*3
+        self.assertArray(self.b3tag[self.mesh], [42]*3)
+
+        del self.b3tag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.b3tag[self.mesh])
+
+    def testRootSetIntArrData(self):
+        self.i3tag[self.mesh] = [42]*3
+        self.assertArray(self.i3tag[self.mesh], [42]*3)
+
+        del self.i3tag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.i3tag[self.mesh])
+
+    def testRootSetDblArrData(self):
+        self.d3tag[self.mesh] = [42]*3
+        self.assertArray(self.d3tag[self.mesh], [42]*3)
+
+        del self.d3tag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.d3tag[self.mesh])
+        
+    def testRootSetEHArrData(self):
+        self.e3tag[self.mesh] = [self.ent]*3
+        self.assertArray(self.e3tag[self.mesh], [self.ent]*3)
+
+        del self.e3tag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.e3tag[self.mesh])
+
+    def testRootSetESHArrData(self):
+        self.s3tag[self.mesh] = [self.set]*3
+        self.assertArray(self.s3tag[self.mesh], [self.set]*3)
+
+        del self.s3tag[self.mesh]
+        self.assertRaises(iBase.TagNotFoundError, lambda: self.s3tag[self.mesh])
+
+
     def testGetAll(self):
         self.itag[self.ent] = 42
         self.dtag[self.ent] = 42
